# mds_jl6276_finalproject

A final project for MDS 2022 Fall. It includes a function that relies on Yelp api, and the funtion takes in a catagory in terms like 'bars', 'restaurant', etc... and return the location of resaurant in New York On map.

## Installation

```bash
$ pip install mds_jl6276_finalproject
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`mds_jl6276_finalproject` was created by Jin Liu. It is licensed under the terms of the MIT license.

## Credits

`mds_jl6276_finalproject` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
